Markdown — bodhi 3.1.0 documentation

# Markdown

## Markdowner service at /markdown

Markdown service

### GET

Accepted content types:

- application/javascript

Given some text, return the markdownified html version.

We use this for “previews” of comments and update notes.

Args:
  request (pyramid.request): The current request. It’s “text” parameter is used to specify the
    text to be processed.
Returns:
  basestring: A JSON object with a single key, html, that indexes the processed text.

Response: jsonp

### GET

Accepted content types:

- application/json
- text/json

Given some text, return the markdownified html version.

We use this for “previews” of comments and update notes.

Args:
  request (pyramid.request): The current request. It’s “text” parameter is used to specify the
    text to be processed.
Returns:
  basestring: A JSON object with a single key, html, that indexes the processed text.

Response: json